#### import the simple module from the paraview
from paraview.simple import *
import numpy as np
#### disable automatic camera reset on 'Show'

# User variables
N_slices = 3
Y_L = np.linspace(0.0, 1.0, N_slices)
Y_L = np.round(Y_L, decimals = 3)
Y = -0.4571 + 0.2221*np.array(Y_L)
n = len(Y_L)
calc = [0]*(3*n)

paraview.simple._DisableFirstRenderCameraReset()

# create a new 'XML Unstructured Grid Reader'
aIR_000 = XMLUnstructuredGridReader(FileName=['/File_Location/AIR_0000.vtu', '/File_Location/AIR_0001.vtu'])

# Loop over all slices
for num, i in enumerate(Y):

    # create a new 'Slice'
    slice1 = Slice(Input=aIR_000)

    # Properties modified on slice1.SliceType
    slice1.SliceType.Origin = [0.0, i, 0.00312500004656613]
    slice1.SliceType.Normal = [0.0, 1.0, 0.0]

    # Properties modified on slice1.SliceType
    slice1.SliceType.Origin = [0.0, i, 0.00312500004656613]
    slice1.SliceType.Normal = [0.0, 1.0, 0.0]

    # create a new 'Integrate Variables'
    integrateVariables1 = IntegrateVariables(Input=slice1)

    # create a new 'Calculator'
    calculator1 = Calculator(Input=integrateVariables1)

    # Properties modified on calculator1
    calculator1.AttributeMode = 'Cell Data'
    calculator1.ResultArrayName = 'P_avg_'+str(Y_L[num])
    calculator1.Function = 'P_G/Area'

    # create a new 'Pass Arrays'
    calc[3*num] = PassArrays(Input=calculator1)

    # Properties modified on passArrays1
    calc[3*num].CellDataArrays = [calculator1.ResultArrayName]

    # rename source object
    RenameSource('P_'+str(Y_L[num]), calc[3*num])

    # create a new 'Calculator'
    calculator1_1 = Calculator(Input=integrateVariables1)

    # Properties modified on calculator1_1
    calculator1_1.AttributeMode = 'Cell Data'
    calculator1_1.ResultArrayName = 'T_avg_'+str(Y_L[num])
    calculator1_1.Function = 'Gas_temperature/Area'

    # create a new 'Pass Arrays'
    calc[3*num+1] = PassArrays(Input=calculator1_1)

    # Properties modified on passArrays1
    calc[3*num+1].CellDataArrays = [calculator1_1.ResultArrayName]

    # rename source object
    RenameSource('T_'+str(Y_L[num]), calc[3*num+1])

    # create a new 'Calculator'
    calculator1_2 = Calculator(Input=integrateVariables1)

    # Properties modified on calculator1_2
    calculator1_2.AttributeMode = 'Cell Data'
    calculator1_2.ResultArrayName = 'EP_G_Avg_'+str(Y_L[num])
    calculator1_2.Function = 'EP_G/Area'

    # create a new 'Pass Arrays'
    calc[3*num+2] = PassArrays(Input=calculator1_2)

    # Properties modified on passArrays1
    calc[3*num+2].CellDataArrays = [calculator1_2.ResultArrayName]

    # rename source object
    RenameSource('EP_G_'+str(Y_L[num]), calc[3*num+2])

# create a new 'Append Attributes'
appendAttributes1 = AppendAttributes(Input=calc)

# create selection
selSource = servermanager.sources.SelectionQuerySource()
selSource.FieldType = "CELL"
selSource.QueryString = "id == 0"
appendAttributes1.SMProxy.SetSelectionInput(appendAttributes1.Port, selSource.SMProxy, 0)

# create a new 'Plot Selection Over Time'
plotSelectionOverTime1 = PlotSelectionOverTime(Input=appendAttributes1,
    Selection=selSource)

# Properties modified on plotSelectionOverTime1
plotSelectionOverTime1.OnlyReportSelectionStatistics = 0

# save data
SaveData('File_Location/Output_Test.csv', proxy=plotSelectionOverTime1, Precision=10)

#### saving camera placements for all active views

# current camera placement for renderView1
# renderView1.CameraPosition = [0.0, 0.0, 1.7762941468841524]
# renderView1.CameraFocalPoint = [0.0, 0.0, 0.0031250000465661287]
# renderView1.CameraParallelScale = 0.45892994538975546

#### uncomment the following to render all views
# RenderAllViews()
# alternatively, if you want to write images, you can use SaveScreenshot(...).